
# Type: creation date


date on which thing was created. This can be applied to nodes or edges

URI: [biolink:creation_date](https://w3id.org/biolink/vocab/creation_date)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Date](types/Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | dcterms:created |

